==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Hatch</name>
    <message>
        <location filename="../Hatch.js" line="+56"/>
        <source>No boundary selected.</source>
        <translation>Nobena obroba ni izbrana.</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Loop not closed at point %1/%2.</source>
        <translation>Zanka ni zaklučena na točki %1/%2.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation>Vsaka entiteta obrobe mora biti črta, krog, elipsa, lok, lok elipse, lomljenka ali krivulja. Najdeno:</translation>
    </message>
    <message>
        <location filename="../HatchInit.js" line="+2"/>
        <source>&amp;Hatch</source>
        <translation>Š&amp;rafura</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw hatch or solid fill</source>
        <translation>Nariši šrafuro ali polnilo</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Šrafura</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Polnilo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Vzorec šrafure</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Vzorec</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Razmerje:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Hatch/ts/Hatch_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Hatch</name>
    <message>
        <source>No boundary selected.</source>
        <translation type="vanished">Nobena obroba ni izbrana.</translation>
    </message>
    <message>
        <source>Loop not closed at point %1/%2.</source>
        <translation type="vanished">Zanka ni zaklučena na točki %1/%2.</translation>
    </message>
    <message>
        <source>Each boundary entity must be a line, arc, circle, ellipse arc, ellipse, polyline or spline. Found:</source>
        <translation type="vanished">Vsaka entiteta obrobe mora biti črta, krog, elipsa, lok, lok elipse, lomljenka ali krivulja. Najdeno:</translation>
    </message>
    <message>
        <location filename="../Hatch.js" line="+72"/>
        <source>Hatch Tools</source>
        <translation>Orodja šrafure</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show hatch tools</source>
        <translation>Prikaži orodja šrafur</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Hatch</source>
        <translation>Š&amp;rafura</translation>
    </message>
    <message>
        <source>Draw hatch or solid fill</source>
        <translation type="vanished">Nariši šrafuro ali polnilo</translation>
    </message>
</context>
<context>
    <name>HatchDialog</name>
    <message>
        <location filename="../HatchDialog.ui" line="+17"/>
        <source>Hatch</source>
        <translation>Šrafura</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Type</source>
        <translation>Vrsta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Solid Fill</source>
        <translation>Polnilo</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Hatch Pattern</source>
        <translation>Vzorec šrafure</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Preview</source>
        <translation>Predogled</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Pattern</source>
        <translation>Vzorec</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Angle:</source>
        <translation>Kot:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Scale:</source>
        <translation>Razmerje:</translation>
    </message>
</context>
</TS>
